#
# spec file for package cabal-rpm
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cabal-rpm
Version:        0.12.4
Release:        2.3
Summary:        RPM packaging tool for Haskell Cabal-based packages
License:        GPL-3.0-or-later
Group:          Development/Tools/Other
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-client-tls-devel
BuildRequires:  ghc-http-conduit-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unix-devel
Recommends:     cabal-install
Recommends:     ghc
Recommends:     yum-utils

%description
This package provides a RPM packaging tool for Haskell Cabal-based packages.

cabal-rpm has commands to generate a RPM spec file and srpm for a package.
It can rpmbuild packages, yum/dnf install their dependencies, prep packages,
and install them. There are commands to list package dependencies and missing
dependencies. The diff command compares the current spec file with a freshly
generated one, the update command updates the spec file to latest version from
Stackage or Hackage, and the refresh command updates the spec file to the
current cabal-rpm packaging. It also handles Hackage revisions of packages.

%prep
%setup -q

%build
%ghc_bin_build

%install
%ghc_bin_install
install -p -m 0644 -D man/cabal-rpm.1 %{buildroot}%{_mandir}/man1/cabal-rpm.1

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/%{name}
%{_mandir}/man1/cabal-rpm.1%{?ext_man}

%changelog
* Tue Jul 10 2018 psimons@suse.com
- Update cabal-rpm to version 0.12.4.
  * 0.12.4 (2018-05-31)
  - now uses Hackage revisions of packages
  - spec --stream STREAM replaces --hackage
  - disable https for ghc < 7.10
  * 0.12.3 (2018-05-14)
  - build: remove erroneous tarball check
  - refresh: use cblrpm for old cabal-rpm
* Thu Apr 12 2018 psimons@suse.com
- Update cabal-rpm to version 0.12.2.
  A more detailed change log is not available.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 0.11.1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.11 with cabal2obs.
* Sun Dec  4 2016 psimons@suse.com
- Update to version 0.10.1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.10.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.9.11 revision 0 with cabal2obs.
* Sat May  7 2016 mimi.vx@gmail.com
- update to 0.9.11
  * build with Cabal-1.24
* Fri Mar 25 2016 mimi.vx@gmail.com
- update to 0.9.10
  * update no longer tries to grep non-existent .git
  * fix duplicate clibs
  * fix build with ghc-8.0
  * SuSE improvements: no disttag or rpmdev-bumpspec
* Mon Jan 25 2016 mimi.vx@gmail.com
- update to 0.9.9
- drop remove_exclusivearch.patch
- drop cabal-rpm.1 manpage, use instead link to upstream cblrpm.1
  * couple of minor improvements for SUSE packaging
* Mon Oct 12 2015 mimi.vx@gmail.com
- update to 0.9.8
  * better %%license logic
  * fix handling of versions without '.'
  * no duplicate test deps
  * drop fix-macro-licence.patch
* Mon Aug 31 2015 mimi.vx@gmail.com
- change fix-macro-license.patch to upstream solution
* Sun Aug 30 2015 mimi.vx@gmail.com
- update to 0.9.7
  * only list buildable executables in spec file
  * bring back 'build' as an alias for 'local'
  * use %%license macro
  * do not warn about missing optional system programs
  + add fix-macro-license.patch to correct use of %%license macro
* Fri May 22 2015 mimi.vx@gmail.com
- update to 0.9.6
  * make "cabal list" quiet
  * filter missing packages from repoquery
  * remove unneeded ghc-old-locale dep
* Mon May  4 2015 mimi.vx@gmail.com
- update to 0.9.5.1
  * add '-old-locale' Cabal flag to fix build on ghc-7.10
* Sun Apr 26 2015 mimi.vx@gmail.com
- update to 0.9.5
- fix for dnf repoquery
- create SOURCES/ for tarball
- fixes for Cabal-1.22
- nogpgcheck for Fedora 22+
- warn about hidden backup spec files
* Tue Mar 10 2015 mpluskal@suse.com
- Recommend cabal-install and ghc as they are necessary for usage
* Wed Feb 18 2015 mimi.vx@gmail.com
- Bump to version 0.9.4
  + remove requires-space.patch
  * use dnf if installed instead of yum for install and repoquery
  * update now only commits changes and new source if git origin is ssh
  * allow Cabal-1.22
* Sun Feb 15 2015 mimi.vx@gmail.com
- add requires-space.patch
* Sat Feb 14 2015 mimi.vx@gmail.com
- Bump to version 0.9.3
  * make sure tarball destdir exists before copying
  + improve output for listing missing packages
  + update improvements: new-sources first, continue if patch fails, git commit changes
  + spec: sort executables and use %%pkg_name in %%ghc_fix_dynamic_rpath
  + drop the debuginfo handling for C files
  + ignore emacs temp ".#pkgname.spec" files-
* Mon Feb  2 2015 jmatejka@suse.cz
- Bump to version 0.9.2
- drop the patches which have been upstream since 0.9.0
- drop useless _service file
- Change license to GPL-3+ albeit upstream delcares GPL-3 since GPL-3+
  should be compatible and is generated by the cabal-rpm
- spec-cleaner cleanups
* Sun Nov 23 2014 peter.trommler@ohm-hochschule.de
- expand macro in spec name tag
  * OBS does not expand macor in name tag and gets confused
- remove rpmlintrc file
  * executable stack issue is fixed in ghc-7.8
* Mon Jul 14 2014 peter.trommler@ohm-hochschule.de
- enable for all archs
* Mon Jul 14 2014 peter.trommler@ohm-hochschule.de
- update to 0.8.11 by Jan Matejka
- fix suse-packaging patch
  * use expanded pkgname in spec name tag
  Factory checks do not expand macros in name tag and fail
* Wed Oct  9 2013 peter.trommler@ohm-hochschule.de
- update to 0.8.6 from upstream
  * provide -static in devel packages
  * pkgconfig quoting
  * make cblrpm-diff quieter
  * fix repoquery for C deps
  * check for _darcs or .git dir in package topdir not in pwd
- refresh cabal-rpm-spdx.patch
- update and refresh suse-packaging.patch
  * add %%defattr(-,root,root-) to all %%files sections
* Fri Sep 27 2013 peter.trommler@ohm-hochschule.de
- update cabal-rpm-spdx.patch
  * fix string for GPL+ license
- update suse-packaging.patch
  * add Group tags
* Wed Sep 25 2013 peter.trommler@ohm-hochschule.de
- update to 0.8.3 from upstream
  * install only missing dependencies
  * wrap description
  * sort dependencies
- refresh cabal-rpm-spdx.patch
  * add Apache license strings
- refresh suse-packaging.patch
  * remove %%{_isa} macros
- move to group Development/Tools
- new BR ghc-regex-compat-devel
* Fri Jun 21 2013 peter.trommler@ohm-hochschule.de
- update to upstream 0.8.0 release on hackage
- refreshed patches cabal-rpm-spdx.patch and suse-packaging.patch
* Mon May 13 2013 peter.trommler@ohm-hochschule.de
- fixed patch suse-packaging.patch
  * missing braces in BuildRoot tag
  * fix double ghc- prefix in library packages
  * spelling of Url rather than URL tag
  * add %%defattr to file sections
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- refreshed patches cabal-rpm-spdx.patch and suse-packaging.patch
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 0.8.0 from git
- implements simplified packaging
  * more transparent as no RPM sections are generated by macros
  and hence it is easier for our review team to understand
  Haskell spec files
* Mon Apr 29 2013 peter.trommler@ohm-hochschule.de
- rebased patches
* Mon Apr 29 2013 peter.trommler@ohm-hochschule.de
- update to 0.7.1 from upstream
- cabal-rpm renamed to cblrpm
- new commands for spec, srpm, and build
- warning when spec exists already
- handle packages that end in a digit
- map curl to libcurl
* Wed Jan  2 2013 peter.trommler@ohm-hochschule.de
- update cabal-rpm-spdx.patch
  * BSD-4-Clause spelling
* Wed Jan  2 2013 peter.trommler@ohm-hochschule.de
- update suse-packaging.patch
  * fix warning date defined but not used
* Wed Jan  2 2013 peter.trommler@ohm-hochschule.de
- patch for openSUSE packaging guidelines
* Fri Dec 28 2012 peter.trommler@ohm-hochschule.de
- patch to generate SPDX license tags
* Fri Dec 28 2012 peter.trommler@ohm-hochschule.de
- a update to 0.6.6 from upstream
  * generate depends for extra-libraries, build-tools, and pkgconfig-depends
  * simplify BuildRequires without versions and drop explicit hscolour
* Sat Oct 13 2012 peter.trommler@ohm-hochschule.de
- Initial packaging.
